/***************************************************************************
 *   kio-locate: KDE I/O Slave for the locate command                      *
 *                                                                         *
 *   Copyright (C) 2004 by Armin Straub                                    *
 *   linux@arminstraub.de                                                  *
 *                                                                         *
 *   This program was initially written by Michael Schuerig.               *
 *   Although I have completely rewritten it, most ideas are adopted       *
 *   from his original work.                                               *
 *                                                                         *
 *   Copyright (C) 2002 by Michael Schuerig                                *
 *   michael@schuerig.de                                                   *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#ifndef PATTERN_H
#define PATTERN_H

#include <qregexp.h>
#include <qstring.h>
#include <qvaluelist.h>

/**
 * Regular Expression adapted to the needs of kio-locate.
 */
class LocateRegExp
{
public:
    /**
     * Constructor
     * @param pattern the pattern to start with
     * @param ignoreCase specifies, if the search should be case sensitive
     */
    LocateRegExp(const QString& pattern, bool ignoreCase);
    LocateRegExp();

    virtual ~LocateRegExp();

    /**
     * Determines whether a file name is matching this regular expression.
     * @param file the filename to match
     */
    virtual bool isMatching(const QString& file);

    /**
     * Set the pattern.
     * @param pattern the pattern to search for. It may be prepended by an
     * exclamation mark, to invert its meaning.
     */
    virtual void setPattern(const QString& pattern);
    
    /**
     * Get the pattern.
     * @return search pattern
     */
    virtual QString getPattern() const;
     
private:
    bool m_negated;
    bool m_ignoreCase;
    QRegExp m_regExp;
    QString m_pattern;
};

/**
 * List of regular expressions
 */
typedef QValueList<LocateRegExp> LocateRegExpList;


#endif
